import { useState } from 'react'
import { useNavigate } from 'react-router-dom'
import { useLocalStorage } from '../hooks/useLocalStorage'
import type { SavedChecklist } from '../types'

function Home() {
  const [checklistName, setChecklistName] = useState('')
  const [isCreating, setIsCreating] = useState(false)
  const navigate = useNavigate()
  const { savedChecklists, saveChecklist, deleteChecklist } = useLocalStorage()

  const createChecklist = async () => {
    if (!checklistName.trim()) return

    setIsCreating(true)
    try {
      const response = await fetch('/api/checklists', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ name: checklistName.trim() }),
      })

      if (response.ok) {
        const data = await response.json()
        const newChecklist: SavedChecklist = {
          uuid: data.uuid,
          name: checklistName.trim(),
          createdAt: new Date().toISOString(),
        }

        // Save to local storage
        saveChecklist(newChecklist)

        // Navigate to the new checklist
        navigate(`/${data.uuid}`)
      } else {
        alert('Failed to create checklist')
      }
    } catch (error) {
      console.error('Error creating checklist:', error)
      alert('Failed to create checklist')
    } finally {
      setIsCreating(false)
      setChecklistName('')
    }
  }

  const handleDeleteChecklist = (uuid: string) => {
    deleteChecklist(uuid)
  }

  // Note: handleUpdateChecklistName is available for future use
  // const handleUpdateChecklistName = (uuid: string, newName: string) => {
  //   updateChecklistName(uuid, newName)
  // }

  return (
    <div className="min-h-screen bg-gray-50 dark:bg-gray-900">
      <div className="max-w-4xl mx-auto px-4 py-12">

        {/* Create New Checklist Section */}
        <div className="bg-white dark:bg-gray-800 rounded-lg shadow-sm border border-gray-200 dark:border-gray-700 p-8 mb-8">
          <h2 className="text-2xl font-bold text-gray-900 dark:text-white mb-6">Create New Checklist</h2>
          <div className="flex gap-4">
            <input
              type="text"
              placeholder="Enter checklist name..."
              value={checklistName}
              onChange={(e) => setChecklistName(e.target.value)}
              onKeyPress={(e) => e.key === 'Enter' && createChecklist()}
              disabled={isCreating}
              className="flex-1 px-4 py-3 border border-gray-300 dark:border-gray-600 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent disabled:bg-gray-100 dark:disabled:bg-gray-700 disabled:text-gray-500 dark:disabled:text-gray-400 bg-white dark:bg-gray-700 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
            />
            <button 
              onClick={createChecklist} 
              disabled={isCreating || !checklistName.trim()}
              className="px-8 py-3 bg-blue-600 dark:bg-blue-500 text-white font-medium rounded-lg hover:bg-blue-700 dark:hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 dark:focus:ring-offset-gray-800 disabled:opacity-50 disabled:cursor-not-allowed transition-colors duration-200"
            >
              {isCreating ? 'Creating...' : 'Create'}
            </button>
          </div>
        </div>

        {/* Saved Checklists Section */}
        {savedChecklists.length > 0 && (
          <div className="bg-white dark:bg-gray-800 rounded-lg shadow-sm border border-gray-200 dark:border-gray-700 p-8">
            <h2 className="text-2xl font-bold text-gray-900 dark:text-white mb-6">Your Checklists</h2>
            <div className="space-y-4">
              {savedChecklists.map((checklist) => (
                <div key={checklist.uuid} className="flex items-center justify-between p-4 border border-gray-200 dark:border-gray-700 rounded-lg hover:bg-gray-50 dark:hover:bg-gray-700 transition-colors duration-200">
                  <div className="flex-1">
                    <h3 className="text-lg font-semibold text-gray-900 dark:text-white mb-1">{checklist.name}</h3>
                    <p className="text-sm text-gray-500 dark:text-gray-400">
                      Created: {new Date(checklist.createdAt).toLocaleDateString()}
                    </p>
                  </div>
                  <div className="flex items-center gap-3">
                    <button 
                      onClick={() => navigate(`/${checklist.uuid}`)}
                      className="px-4 py-2 bg-blue-600 dark:bg-blue-500 text-white font-medium rounded-lg hover:bg-blue-700 dark:hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 dark:focus:ring-offset-gray-800 transition-colors duration-200"
                    >
                      Open
                    </button>
                    <button 
                      onClick={() => handleDeleteChecklist(checklist.uuid)}
                      className="px-4 py-2 bg-red-600 dark:bg-red-500 text-white font-medium rounded-lg hover:bg-red-700 dark:hover:bg-red-600 focus:outline-none focus:ring-2 focus:ring-red-500 focus:ring-offset-2 dark:focus:ring-offset-gray-800 transition-colors duration-200"
                    >
                      Delete
                    </button>
                  </div>
                </div>
              ))}
            </div>
          </div>
        )}

        {/* Empty State */}
        {savedChecklists.length === 0 && (
          <div className="bg-white dark:bg-gray-800 rounded-lg shadow-sm border border-gray-200 dark:border-gray-700 p-12 text-center">
            <div className="text-gray-400 dark:text-gray-500 text-6xl mb-4">📋</div>
            <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-2">No checklists yet</h3>
            <p className="text-gray-600 dark:text-gray-300">Create your first checklist above to get started!</p>
          </div>
        )}
      </div>
    </div>
  )
}

export default Home 